public inbox for gentoo-commits@lists.gentoo.org
 help / color / mirror / Atom feed
* [gentoo-commits] proj/elfix:elfix-0.8.x commit in: tests/revdeppaxtest/
@ 2012-12-29 12:52 Anthony G. Basile
  0 siblings, 0 replies; only message in thread
From: Anthony G. Basile @ 2012-12-29 12:52 UTC (permalink / raw
  To: gentoo-commits

commit:     e425311072fd1d289fbaa27baa23e788c7fed72e
Author:     Anthony G. Basile <blueness <AT> gentoo <DOT> org>
AuthorDate: Sat Dec 29 05:39:38 2012 +0000
Commit:     Anthony G. Basile <blueness <AT> gentoo <DOT> org>
CommitDate: Sat Dec 29 12:50:20 2012 +0000
URL:        http://git.overlays.gentoo.org/gitweb/?p=proj/elfix.git;a=commit;h=e4253110

tests/revdeppaxtest/revdeptest.sh: update to work with new revdep-pax

---
 tests/revdeppaxtest/revdeptest.sh |   31 ++++++++++---------------------
 1 files changed, 10 insertions(+), 21 deletions(-)

diff --git a/tests/revdeppaxtest/revdeptest.sh b/tests/revdeppaxtest/revdeptest.sh
index 2bbfb56..6512959 100755
--- a/tests/revdeppaxtest/revdeptest.sh
+++ b/tests/revdeppaxtest/revdeptest.sh
@@ -45,23 +45,16 @@ RM="/bin/rm -f"
 MKDIR="/bin/mkdir -p"
 RMDIR="/bin/rmdir"
 LDD="/usr/bin/ldd"
-LDCONFIG="/sbin/ldconfig"
-LDCONFIGD="/etc/ld.so.conf.d/revdeptest.conf"
 
 
-# create a ld.so.conf.d/ file
-cat << EOF > "${LDCONFIGD}"
-${LIBSPATH}
-EOF
-${LDCONFIG}
-
-# create our /var/db/pkg/${CAT}/${PKG}/NEEDED
+# create our /var/db/pkg/${CAT}/${PKG}/NEEDED.ELF.2
 CAT="zzz"
 PKG="revdepbin-1"
 VARDBPKG="/var/db/pkg"
 ${MKDIR} "${VARDBPKG}/${CAT}/${PKG}"
-cat << EOF > "${VARDBPKG}/${CAT}/${PKG}/NEEDED"
-${LIBSPATH}/${BINARY} ${SONAME}
+cat << EOF > "${VARDBPKG}/${CAT}/${PKG}/NEEDED.ELF.2"
+XYZ;${LIBSPATH}/${BINARY};;;${SONAME}
+XYZ;${LIBSPATH}/${LIBRARY};${SONAME};;
 EOF
 
 if [ "${verbose}" = 0 ] ;then
@@ -104,14 +97,14 @@ do
 		$PAXCTLNG -m${lf}  "${LIBSPATH}/${LIBRARY}"
 
 		p=$($PAXCTLNG -v ${LIBSPATH}/${BINARY})
-		p=$(echo $p | awk '{ print $3 }')
+		p=$(echo $p | awk '{ print $4 }')
 		if [ "${verbose}" != 0 ] ;then
 			echo " BEFORE: "
 			echo "  Binary:  $p"
 		fi
 
 		p=$($PAXCTLNG -v ${LIBSPATH}/${LIBRARY})
-		p=$(echo $p | awk '{ print $3 }')
+		p=$(echo $p | awk '{ print $4 }')
 		if [ "${verbose}" != 0 ] ;then
 			echo "  Library: $p"
 		fi
@@ -119,14 +112,14 @@ do
 		$REVDEPPAX -m -y -s ${SONAME} >/dev/null 2>&1
 
 		ba=$($PAXCTLNG -v ${LIBSPATH}/${BINARY})
-		ba=$(echo $ba | awk '{ print $3 }')
+		ba=$(echo $ba | awk '{ print $4 }')
 		if [ "${verbose}" != 0 ] ;then
 			echo " AFTER: "
 			echo "  Binary:  $ba"
 		fi
 
 		p=$($PAXCTLNG -v ${LIBSPATH}/${LIBRARY})
-		p=$(echo $p | awk '{ print $3 }')
+		p=$(echo $p | awk '{ print $4 }')
 		if [ "${verbose}" != 0 ] ;then
 			echo "  Library: $p"
 		fi
@@ -165,15 +158,11 @@ done
 # do test here
 #
 
-# clean up our /var/db/pkg/${CAT}/${PKG}/NEEDED
-${RM} ${VARDBPKG}/${CAT}/${PKG}/NEEDED
+# clean up our /var/db/pkg/${CAT}/${PKG}/NEEDED.ELF.2
+${RM} ${VARDBPKG}/${CAT}/${PKG}/NEEDED.ELF.2
 ${RMDIR} ${VARDBPKG}/${CAT}/${PKG}
 ${RMDIR} ${VARDBPKG}/${CAT}
 
-# clean up our ld.so.conf.d/ file
-${RM} ${LDCONFIGD}
-${LDCONFIG}
-
 if [ "${verbose}" = 0 ] ;then
 	echo
 	echo


^ permalink raw reply related	[flat|nested] only message in thread

only message in thread, other threads:[~2012-12-29 12:52 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2012-12-29 12:52 [gentoo-commits] proj/elfix:elfix-0.8.x commit in: tests/revdeppaxtest/ Anthony G. Basile

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox